@@ -494,14 +494,18 @@ async def sync_preseem_model(preseem_model,
                     site = site_names.get(router.site)
                     router._site_uuid = site.uuid
 
-            await _sync_objects(preseem_model,
-                                company_uuid,
-                                source,
-                                routers,
-                                router_discs,
-                                preseem_model.Element.CreateElementDiscovery,
-                                preseem_model.Element.UpdateElementDiscovery,
-                                _router_field_map,
-                                noact=noact)
+            new_objs = await _sync_objects(preseem_model,
+                                           company_uuid,
+                                           source,
+                                           routers,
+                                           router_discs,
+                                           preseem_model.Element.CreateElementDiscovery,
+                                           preseem_model.Element.UpdateElementDiscovery,
+                                           _router_field_map,
+                                           noact=noact)
+            for mobj in new_objs:
+                sobj = routers.get(mobj.source_id)
+                if sobj:
+                    sobj._uuid = mobj.uuid
 
         return uuid_map
