@@ -1,7 +1,10 @@
 """Data structures used to manipulate the model locally within a data source."""
-from .util import normalize_mac
 from collections import namedtuple
 from ipaddress import ip_address, ip_network
+from uuid import UUID
+
+from .grpc_nm_model import NetworkMetadataReference
+from .util import normalize_mac
 from preseem_protobuf.model import service_pb2
 
 
@@ -400,7 +403,9 @@ class Service(Errorable):
 
 class Router(Errorable):
     """Router class to use within a data source."""
-    __slots__ = ["_id", "_community", "_host", "_name", "_site", "_url", "_site_uuid"]
+    __slots__ = [
+        "_id", "_community", "_host", "_name", "_site", "_url", "_site_uuid", "_uuid"
+    ]
     # this is just used to list fields we want to print with __repr__
     attrs = ('id', 'name', 'site', 'host', 'community', 'url')
 
@@ -415,9 +420,27 @@ class Router(Errorable):
         self._site = None
         self._url = None
         self._site_uuid = None  # used by sync_preseem_model for resolution
+        self._uuid = None  # used to pass uuid back from sync_preseem_model
         for key, value in kwargs.items():
             setattr(self, key, value)
 
+    def get_nm(self, system=None):
+        """Return network metadata objects for this object."""
+        ref = NetworkMetadataReference('router', self._id, {})
+        if self._host:
+            ref.attributes['host'] = self._host
+        if self._name:
+            ref.attributes['name'] = self._name
+        if self._site:
+            ref.attributes['site'] = self._site
+        if self._community:
+            ref.attributes['community'] = self._community
+        if self._uuid:
+            ref.attributes['uuid'] = str(UUID(bytes=self._uuid))
+        if system:
+            ref.attributes['system'] = system
+        return [ref]
+
     @property
     def id(self):
         return self._id
@@ -439,7 +462,7 @@ class Router(Errorable):
                 self.err('community', value,
                          "The router 'community' parameter must be non-empty.")
                 return
-        self._community = str(community) if value is not None else None
+        self._community = str(value) if value is not None else None
 
     @property
     def host(self):
