@@ -1189,6 +1189,7 @@ class TestModelSync(unittest.TestCase):
             if site or not sobj.errors:
                 self.assertIsNotNone(site)
                 self.assertEqual(site.uuid, mobj.site_uuid)
+        self.assertEqual(mobj.uuid, sobj._uuid)
 
     def test_router_create(self):
         """An Router is created in the model."""
@@ -1271,3 +1272,12 @@ class TestModelSync(unittest.TestCase):
             router.host = '192.0.2.1'
             await self.checkSourceRouter(router)
         self._await(test())
+
+    def test_router_uuid(self):
+        """The router source object is populated with its uuid after sync."""
+        async def test():
+            router = Router('router01', host='192.0.2.1', name='Router 1', site='Site 1', url='https://myisp.com/routers/router01')
+            routers = {'router01': router}
+            await sync_preseem_model(self.model, self.company.uuid, 'test_source', ElementRole.AP, [], routers=routers)
+            await self.checkSourceRouter(router)
+        self._await(test())
