@@ -4,6 +4,7 @@ from hashlib import sha256
 from uuid import uuid4
 
 from preseem.source_model import Attachment, Router, Service
+from preseem.grpc_nm_model import NetworkMetadataReference
 
 class TestSourceModel(unittest.TestCase):
     def setUp(self):
@@ -101,6 +102,26 @@ class TestSourceModel(unittest.TestCase):
         router.url = None
         self.assertEqual(router.url, None)
 
+    def test_router_nm(self):
+        """Test that the router object generates a good NetworkMetadataReference."""
+        router = Router("r1")
+        ref = NetworkMetadataReference('router', 'r1', {})
+        self.assertEqual(router.get_nm(), [ref])
+        router.host = ref.attributes['host'] = '192.0.2.1'
+        self.assertEqual(router.get_nm(), [ref])
+        router.name = ref.attributes['name'] = 'Router 1'
+        self.assertEqual(router.get_nm(), [ref])
+        router.site = ref.attributes['site'] = 'Site 1'
+        self.assertEqual(router.get_nm(), [ref])
+        router.community = ref.attributes['community'] = 'public'
+        self.assertEqual(router.get_nm(), [ref])
+        ref.attributes['system'] = 'my-system'
+        self.assertEqual(router.get_nm('my-system'), [ref])
+        uuid = uuid4()
+        ref.attributes['uuid'] = str(uuid)
+        router._uuid = uuid.bytes
+        self.assertEqual(router.get_nm('my-system'), [ref])
+
     def test_service_id(self):
         """Test field checking of service.id"""
         with self.assertRaises(TypeError):
@@ -458,4 +479,3 @@ class TestSourceModel(unittest.TestCase):
         del attachment2.network_prefixes[0]
         attachment1.network_prefixes[0] = '2001:db8:1234::/48'
         self.assertEqual(attachment1, attachment2)
-
